@@ -78,6 +78,7 @@ const REPORTING_URL: &str = "https://usage-reporting.api.apollographql.com/api/i
 const TARGET_LOG: &str = "apollo-studio-extension";
 const VERSION: &str = env!("CARGO_PKG_VERSION");
 const RUNTIME_VERSION: &str = "Rust - No runtime version provided yet";
+const MAX_TRACES: usize = 100;
 
 /// An ENUM describing the various HTTP Methods existing.
 #[derive(Debug, Clone)]
@@ -172,8 +173,9 @@ impl ApolloTracing {
     /// * hostname - Hostname like yourdomain-graphql-1.io
     /// * graph_ref - <ref>@<variant> Graph reference with variant
     /// * release_name - Your release version or release name from Git for example
-    /// * batch_target - The number of traces to batch, it depends on your traffic, if you have
-    /// 60 request per minutes, set it to 20.
+    /// * batch_target - The number of traces to batch, it depends on your traffic, if you have.
+    /// You cannot send batch traces with a size over 4Mb, so we batch every 100 traces even if
+    /// your batch_target is set higher.
     pub fn new(
         authorization_token: String,
         hostname: String,
@@ -220,14 +222,13 @@ impl ApolloTracing {
                     None => {
                         let mut trace_and_stats = TracesAndStats::new();
                         trace_and_stats.mut_trace().push(trace);
-
                         hashmap.insert(name, trace_and_stats);
                     }
                 }
 
                 count += 1;
 
-                if count > batch_target {
+                if count > batch_target || count > MAX_TRACES  {
                     use tracing::{field, field::debug, span, Level};
 
                     let span_batch = span!(
